From: Sameer Wadgaonkar <sameer.wadgaon...@unisys.com>

Renamed functions
* chipset_bus_create() to visorchipset_bus_create()
* chipset_bus_destroy() to visorchipset_bus_destroy()

Signed-off-by: Sameer Wadgaonkar <sameer.wadgaon...@unisys.com>
Reported-by: Greg Kroah-Hartman <gre...@linuxfoundation.org>
Signed-off-by: David Kershner <david.kersh...@unisys.com>
---
 drivers/staging/unisys/visorbus/visorbus_main.c    |  4 ++--
 drivers/staging/unisys/visorbus/visorbus_private.h |  4 ++--
 drivers/staging/unisys/visorbus/visorchipset.c     | 10 +++++-----
 3 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/drivers/staging/unisys/visorbus/visorbus_main.c 
b/drivers/staging/unisys/visorbus/visorbus_main.c
index 03e29b5..5ba807c 100644
--- a/drivers/staging/unisys/visorbus/visorbus_main.c
+++ b/drivers/staging/unisys/visorbus/visorbus_main.c
@@ -1077,7 +1077,7 @@ remove_all_visor_devices(void)
 }
 
 int
-chipset_bus_create(struct visor_device *dev)
+visorchipset_bus_create(struct visor_device *dev)
 {
        int err;
 
@@ -1092,7 +1092,7 @@ chipset_bus_create(struct visor_device *dev)
 }
 
 void
-chipset_bus_destroy(struct visor_device *dev)
+visorchipset_bus_destroy(struct visor_device *dev)
 {
        visorbus_remove_instance(dev);
        visorbus_destroy_response(dev, 0);
diff --git a/drivers/staging/unisys/visorbus/visorbus_private.h 
b/drivers/staging/unisys/visorbus/visorbus_private.h
index 4ecfd7b..3c89935 100644
--- a/drivers/staging/unisys/visorbus/visorbus_private.h
+++ b/drivers/staging/unisys/visorbus/visorbus_private.h
@@ -27,8 +27,8 @@
  * command line
  */
 
-int chipset_bus_create(struct visor_device *bus_info);
-void chipset_bus_destroy(struct visor_device *bus_info);
+int visorchipset_bus_create(struct visor_device *bus_info);
+void visorchipset_bus_destroy(struct visor_device *bus_info);
 int chipset_device_create(struct visor_device *dev_info);
 void chipset_device_destroy(struct visor_device *dev_info);
 int chipset_device_pause(struct visor_device *dev_info);
diff --git a/drivers/staging/unisys/visorbus/visorchipset.c 
b/drivers/staging/unisys/visorbus/visorchipset.c
index 3076b77..eea70f4 100644
--- a/drivers/staging/unisys/visorbus/visorchipset.c
+++ b/drivers/staging/unisys/visorbus/visorchipset.c
@@ -630,9 +630,9 @@ visorbus_create(struct controlvm_message *inmsg)
        }
        bus_info->visorchannel = visorchannel;
 
-       /* Response will be handled by chipset_bus_create */
-       err = chipset_bus_create(bus_info);
-       /* If error chipset_bus_create didn't respond, need to respond here */
+       /* Response will be handled by visorchipset_bus_create */
+       err = visorchipset_bus_create(bus_info);
+       /* If visorchipset_bus_create didn't respond, need to respond here */
        if (err)
                goto err_destroy_channel;
 
@@ -688,8 +688,8 @@ visorbus_destroy(struct controlvm_message *inmsg)
                bus_info->pending_msg_hdr = pmsg_hdr;
        }
 
-       /* Response will be handled by chipset_bus_destroy */
-       chipset_bus_destroy(bus_info);
+       /* Response will be handled by visorchipset_bus_destroy */
+       visorchipset_bus_destroy(bus_info);
        return 0;
 
 err_respond:
-- 
git-series 0.9.1
_______________________________________________
devel mailing list
de...@linuxdriverproject.org
http://driverdev.linuxdriverproject.org/mailman/listinfo/driverdev-devel

Reply via email to